==> dekeyrej-pages-0.5.7.tar.gz: dekeyrej-pages-0.5.7/pages/serverpage.py <==
""" ... """
import time
import json
# import base64

import arrow
import socketserver                         # for liveness probe (MyTCPHandler(), TCPServer)
import requests   
from requests.exceptions import HTTPError #, ConnectionError
from requests.adapters   import HTTPAdapter, Retry
# from kubernetes import config, client
from kube                import KubeSecrets

from datasourcelib import Database          # wrapper for postgres/cockroach/sqlite/mongodb

class ServerPage:
    """ ... """
    def __init__(self, prod: bool, period: int, path: str=None):
        self.type = None
        self.prod = prod  # boolean: True for Production, False otherwise
        if self.prod:
            self.ks = KubeSecrets(True)
        self.path = path
        self.rsess = requests.session()
        retries = Retry(total=5,
                        backoff_factor=0.5,
                        status_forcelist=[500, 502, 503, 504])
        self.rsess.mount('https://', HTTPAdapter(max_retries=retries))
        self.secrets = self.read_secrets()
        self.dba = self.connect_db()
        self.update_period = period
        self.last_update = 0
        
    # def read_encrypted_secrets(self):
    #     dd = DecryptDicts()
    #     if self.prod:
    #         dd.read_in_cluster_key()
    #     else:
    #         # dd.read_key_from_cluster()
    #         # REFKEY = os.environ["REFKEY"]
    #         # dd.set_key(REFKEY)
    #         dd.read_key_from_file('Do_Not_Copy/refKey.txt')
    #     return dd.decrypt_dict(encsecrets)

    # def read_kube_secret(self, namespace, secret, datapath, inkube=True):
    #     if inkube:
    #         config.incluster_config.load_incluster_config()
    #     else:
    #         config.load_kube_config()
    #     v1 = client.CoreV1Api()
    #     return json.loads(base64.b64decode(v1.read_namespaced_secret(secret, namespace).data[datapath]).decode('utf-8'))

    def read_json_from_file(self, path):
        with open(path) as file:
            output = json.loads(file.read())
            file.close()
        return output

    def read_secrets(self):
        if self.prod:
            return self.ks.read_secret(namespace='default', secret_name='matrix-secrets',
                                  data_name='secrets.json', data_is_json=True)
            # return self.read_kube_secret("default", "matrix-secrets", "secrets.json", inkube=True)
        else:
            return self.read_json_from_file(self.path)

    def clear_secrets(self):
        self.secrets = None
    
    def connect_db(self):
        """ 
        This is very postgres-centric. Need to allow for SQLite and MongoDB (at least). 
        additional secret keys for dbtype, dbport, dbname, tblname, prodhost and dev/test host.
        """
        DBPORT = self.secrets['db_port']
        DBNAME = 'matrix'
        TBLNAME = 'feed'
        
        if self.prod:
            DBHOST = self.secrets['db_host']
        else:
            DBHOST = '192.168.86.62'  #rocket3
        
        db_params = {"user": self.secrets['dbuser'],
             "pass": self.secrets['dbpass'], \
             "host": DBHOST, "port":  DBPORT, \
             "db_name": DBNAME, "tbl_name": TBLNAME}

        return Database('postgres', db_params)

    def update(self): # really must be overridden...
        """ ... """
        print(f"{type(self).__name__} updated.")

    def check(self, now: float):
        """ ... """
        if self.last_update == 0 or now - self.last_update > self.update_period:
            self.last_update = now
            print(f'Updating {type(self).__name__}...')
            self.update()
            print(f"{arrow.now().to('US/Eastern').format('MM/DD/YYYY h:mm:ss A ZZZ')}: " \
                  f"{type(self).__name__} updated.")

    def run(self):
        """ ... """
        # Write Startup record to database
        tnow = arrow.now()
        data = {}
        data['type']   = f'{self.type}-Server'
        data['updated'] = tnow.to('US/Eastern').format('MM/DD/YYYY h:mm A ZZZ')
        data['valid']   = tnow.to('US/Eastern').format('MM/DD/YYYY h:mm:ss A ZZZ')
        data['values'] = {}
        self.dba.write(data)

        if self.prod:
            HOST = '0.0.0.0'
            PORT = 10255

            class MyTCPHandler(socketserver.BaseRequestHandler):
                # Socket handler for liveness probe
                def handle(self):
                    self.data = self.request.recv(1024).strip()
                    print('Health Check...')
                    self.request.sendall(self.data.upper())

            with socketserver.TCPServer((HOST, PORT), MyTCPHandler) as server:
                server.timeout = 0.1
                while True:
                    now = time.monotonic()
                    self.check(now)
                    server.handle_request()
                    time.sleep(0.9)
        else:
            while True:
                    now = time.monotonic()
                    self.check(now)
                    # server.handle_request()
                    time.sleep(0.95)


    def fetch(self, url: str, name: str, now: str, auth: str=None, headers: str=None): 
        """ ... """
        with self.rsess as sess:
            try:
                if auth is None and headers is None:
                    response = sess.get(url,timeout=(5,15))
                elif headers is None:
                    response = sess.get(url,timeout=(5,15),auth=auth)
                else:
                    response = sess.get(url,timeout=(5,15),headers=headers)
                response.raise_for_status()
            except HTTPError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            except ConnectionError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            # except Exception as err:
            #     print(f'({name}) Other error occurred: {err} @ {now}')
            #     return None
            return response.json()

    def fetch_raw(self, url: str, name: str, now: str):
        """ required for Garmin server which expects an XML response instead of a JSON one """
        with self.rsess as sess:
            try:
                response = sess.get(url,timeout=(5,15))
                response.raise_for_status()
            except HTTPError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            except ConnectionError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            # except Exception as err:
            #     print(f'({name}) Other error occurred: {err} @ {now}')
            #     return None
            return response

    def now_str(self, now: arrow, secs: bool):
        """ ... """
        if secs:
            return now.format('MM/DD/YYYY h:mm:ss A ZZZ')

        return now.format('MM/DD/YYYY h:mm A ZZZ')

==> dekeyrej-pages-0.5.11.tar.gz: dekeyrej-pages-0.5.11/pages/serverpage.py <==
""" ... """
import time
import json
# import base64

import arrow
import socketserver                         # for liveness probe (MyTCPHandler(), TCPServer)
import requests   
from requests.exceptions import HTTPError #, ConnectionError
from requests.adapters   import HTTPAdapter, Retry
import redis
# from kubernetes import config, client
from kube                import KubeSecrets

from datasourcelib import Database          # wrapper for postgres/cockroach/sqlite/mongodb

class ServerPage:
    """ ... """
    def __init__(self, prod: bool, period: int, path: str=None):
        self.type = None
        self.prod = prod  # boolean: True for Production, False otherwise
        if self.prod:
            self.ks = KubeSecrets(True)
        self.path = path
        self.rsess = requests.session()
        retries = Retry(total=5,
                        backoff_factor=0.5,
                        status_forcelist=[500, 502, 503, 504])
        self.rsess.mount('https://', HTTPAdapter(max_retries=retries))
        self.secrets = self.read_secrets()
        self.dba = self.connect_db()
        self.r = self.connect_redis()
        self.update_period = period
        self.last_update = 0
        self.output = False
        
    # def read_encrypted_secrets(self):
    #     dd = DecryptDicts()
    #     if self.prod:
    #         dd.read_in_cluster_key()
    #     else:
    #         # dd.read_key_from_cluster()
    #         # REFKEY = os.environ["REFKEY"]
    #         # dd.set_key(REFKEY)
    #         dd.read_key_from_file('Do_Not_Copy/refKey.txt')
    #     return dd.decrypt_dict(encsecrets)

    # def read_kube_secret(self, namespace, secret, datapath, inkube=True):
    #     if inkube:
    #         config.incluster_config.load_incluster_config()
    #     else:
    #         config.load_kube_config()
    #     v1 = client.CoreV1Api()
    #     return json.loads(base64.b64decode(v1.read_namespaced_secret(secret, namespace).data[datapath]).decode('utf-8'))

    def read_json_from_file(self, path):
        with open(path) as file:
            output = json.loads(file.read())
            file.close()
        return output

    def read_secrets(self):
        if self.prod:
            return self.ks.read_secret(namespace='default', secret_name='matrix-secrets',
                                  data_name='secrets.json', data_is_json=True)
            # return self.read_kube_secret("default", "matrix-secrets", "secrets.json", inkube=True)
        else:
            return self.read_json_from_file(self.path)

    def clear_secrets(self):
        self.secrets = None

    def connect_redis(self):
        if self.secrets['rpass'] == 'None':
            r = redis.Redis(host=self.secrets['rhost'], port=6379, db=0, decode_responses=True)
        else:
            r = redis.Redis(host=self.secrets['rhost'], port=6379, db=0, decode_responses=True, 
                                 password=self.secrets['rpass'])
        return r
    
    def connect_db(self):
        """ 
        This is very postgres-centric. Need to allow for SQLite and MongoDB (at least). 
        additional secret keys for dbtype, dbport, dbname, tblname, prodhost and dev/test host.
        """
        DBPORT = self.secrets['db_port']
        DBNAME = 'matrix'
        TBLNAME = 'feed'
        
        if self.prod:
            DBHOST = self.secrets['db_host']
        else:
            DBHOST = '192.168.86.62'  #rocket3
        
        db_params = {"user": self.secrets['dbuser'],
             "pass": self.secrets['dbpass'], \
             "host": DBHOST, "port":  DBPORT, \
             "db_name": DBNAME, "tbl_name": TBLNAME}

        return Database('postgres', db_params)

    def update(self): # really must be overridden...
        """ ... """
        print(f"{type(self).__name__} updated.")

    def check(self, now: float):
        """ ... """
        if self.last_update == 0 or now - self.last_update > self.update_period:
            self.last_update = now
            print(f'Updating {type(self).__name__}...')
            self.update()
            self.r.publish('update', self.type)
            print(f"{arrow.now().to('US/Eastern').format('MM/DD/YYYY h:mm:ss A ZZZ')}: " \
                  f"{type(self).__name__} updated.")

    def run(self):
        """ ... """
        # Write Startup record to database
        tnow = arrow.now()
        data = {}
        data['type']   = f'{self.type}-Server'
        data['updated'] = tnow.to('US/Eastern').format('MM/DD/YYYY h:mm A ZZZ')
        data['valid']   = tnow.to('US/Eastern').format('MM/DD/YYYY h:mm:ss A ZZZ')
        data['values'] = {}
        self.dba.write(data)

        if self.prod:
            HOST = '0.0.0.0'
            PORT = 10255

            class MyTCPHandler(socketserver.BaseRequestHandler):
                # Socket handler for liveness probe
                def handle(self):
                    self.data = self.request.recv(1024).strip()
                    print('Health Check...')
                    self.request.sendall(self.data.upper())

            with socketserver.TCPServer((HOST, PORT), MyTCPHandler) as server:
                server.timeout = 0.1
                while True:
                    now = time.monotonic()
                    self.check(now)
                    server.handle_request()
                    time.sleep(0.9)
        else:
            while True:
                    now = time.monotonic()
                    self.check(now)
                    # server.handle_request()
                    time.sleep(0.95)


    def fetch(self, url: str, name: str, now: str, auth: str=None, headers: str=None): 
        """ ... """
        with self.rsess as sess:
            try:
                if auth is None and headers is None:
                    response = sess.get(url,timeout=(5,15))
                elif headers is None:
                    response = sess.get(url,timeout=(5,15),auth=auth)
                else:
                    response = sess.get(url,timeout=(5,15),headers=headers)
                response.raise_for_status()
            except HTTPError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            except ConnectionError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            # except Exception as err:
            #     print(f'({name}) Other error occurred: {err} @ {now}')
            #     return None
            else:
                try:
                    if self.output:
                        print(response)
                        print(f'apparent_encoding: [{response.apparent_encoding}]')
                        print(f'content: [{response.content}]')
                        print(f'   text: [{response.text}]')
                    values = response.json()
                except json.decoder.JSONDecodeError:
                    raise
                else:
                    return values # response.json()

    def fetch_raw(self, url: str, name: str, now: str):
        """ required for Garmin server which expects an XML response instead of a JSON one """
        with self.rsess as sess:
            try:
                response = sess.get(url,timeout=(5,15))
                response.raise_for_status()
            except HTTPError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            except ConnectionError as http_err:
                print(f'({name}) HTTP error occurred: {http_err} @ {now}')
                return None
            # except Exception as err:
            #     print(f'({name}) Other error occurred: {err} @ {now}')
            #     return None
            return response

    def now_str(self, now: arrow, secs: bool):
        """ ... """
        if secs:
            return now.format('MM/DD/YYYY h:mm:ss A ZZZ')

        return now.format('MM/DD/YYYY h:mm A ZZZ')
